@@ -210,6 +210,8 @@ def resolve_common_transfer_errors(output, is_stagein=True):  # noqa: C901
         ret = get_error_info(ErrorCodes.UNREACHABLENETWORK, 'NETWORK_UNREACHABLE', output)
     elif "Run: [ERROR] Server responded with an error" in output:
         ret = get_error_info(ErrorCodes.XRDCPERROR, 'XRDCP_ERROR', output)
+    elif "Unable to locate credentials" in output:
+        ret = get_error_info(ErrorCodes.MISSINGCREDENTIALS, 'S3_ERROR', output)
 
     # reg exp the output to get real error message
     ret = output_line_scan(ret, output)
